<?php

/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * This function reads in the options from theme mods and determines whether a CSS rule is needed to implement an
 * option. CSS is only written for choices that are non-default in order to avoid adding unnecessary CSS. All options
 * are also filterable allowing for more precise control via a child theme or plugin.
 *
 * Note that all CSS for options is present in this function except for the CSS for fonts and the logo, which require
 * a lot more code to implement.
 *
 * @return void
 */
function diamond_css_add_rules() {
    /**
     * Colors section
     */
    diamond_css_add_simple_color_rule( 'color-body-text', 'body', 'color' );

    diamond_css_add_simple_color_rule( 'color-logo', '#logo h1 a, #logo h1 a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-link', 'a', 'color' );
    diamond_css_add_simple_color_rule( 'color-link-hover', 'a:hover', 'color' );

    // Breadcrumbs
    diamond_css_add_simple_color_rule( 'color-breadcrumbs-background', '.breadcrumbs', 'background-color' );
    diamond_css_add_simple_color_rule( 'color-breadcrumbs', '.breadcrumbs a, .breadcrumbs .separator', 'color' );
    diamond_css_add_simple_color_rule( 'color-breadcrumbs-separator', '.breadcrumbs .separator', 'color' );
    diamond_css_add_simple_color_rule( 'color-breadcrumbs-current', '.breadcrumbs .current', 'color' );

    // Menu
    diamond_css_add_simple_color_rule( 'color-menu-link', '.dropdown a', 'color' );
    diamond_css_add_simple_color_rule( 'color-menu-link-hover', '.dropdown a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-menu-link-current', 'li.current-menu-item a, li.current_page_item a, li.current-menu-ancestor a, li.current-menu-parent a, li.current_page_parent  a', 'color' );
    diamond_css_add_simple_color_rule( 'color-menu-hamburger-background', '.navbar-toggle', 'background' );

    // Post
    diamond_css_add_simple_color_rule( 'color-post-title', '#recent-posts h2.title a, #recent-posts h2.title a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-post-title-hover', '#recent-posts h2.title a:hover', 'color' );

    diamond_css_add_simple_color_rule( 'color-post-meta', '.post-meta, .post-meta a, .post-meta a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-post-meta-link-hover', '.post-meta a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-post-meta-separator', '.post-meta .separator', 'color' );

    diamond_css_add_simple_color_rule( 'color-post-separator', 'h1.entry-title, .post_author, #comments, .commentlist, #recent-posts .post-meta', 'border-color' );

    // Widgets
    diamond_css_add_simple_color_rule( 'color-widget-title', '#sidebar .widget h3.title, #sidebar-left .widget h3.title, #footer .widget h3.title', 'color' );
    diamond_css_add_simple_color_rule( 'color-widget-separator', '#sidebar .widget', 'border-color' );

    diamond_css_add_simple_color_rule( 'color-button-background', 'button, input[type=button], input[type=reset], input[type=submit]', 'background-color' );

    // Footer
    diamond_css_add_simple_color_rule( 'color-footer-text', '#footer', 'color' );
    diamond_css_add_simple_color_rule( 'color-footer-link', '#footer a, #footer a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-footer-link-hover', '#footer a:hover', 'color' );
    diamond_css_add_simple_color_rule( 'color-footer-separator', '#footer .widgets', 'border-color' );

    /**
     * Header Background
     */
    diamond_css_add_simple_color_rule( 'header-background-color', '#header', 'background-color' );

    $header_background_image = get_theme_mod( 'header-background-image', diamond_get_default( 'header-background-image' ) );
    if ( ! empty( $header_background_image ) ) {
        $header_background_image    = addcslashes( esc_url_raw( $header_background_image ), '"' );
        $header_background_size     = get_theme_mod( 'header-background-size', diamond_get_default( 'header-background-size' ) );
        $header_background_repeat   = get_theme_mod( 'header-background-repeat', diamond_get_default( 'header-background-repeat' ) );
        $header_background_position = get_theme_mod( 'header-background-position', diamond_get_default( 'header-background-position' ) );

        diamond_get_css()->add( array(
            'selectors'    => array( '#header' ),
            'declarations' => array(
                'background-image'    => 'url("' . $header_background_image . '")',
                'background-size'     => $header_background_size,
                'background-repeat'   => $header_background_repeat,
                'background-position' => $header_background_position . ' center'
            )
        ) );
    }

    /**
     * Footer Background
     */
    diamond_css_add_simple_color_rule( 'footer-background-color', '#footer', 'background-color' );

    $footer_background_image = get_theme_mod( 'footer-background-image', diamond_get_default( 'footer-background-image' ) );
    if ( ! empty( $footer_background_image ) ) {
        $footer_background_image    = addcslashes( esc_url_raw( $footer_background_image ), '"' );
        $footer_background_size     = get_theme_mod( 'footer-background-size', diamond_get_default( 'footer-background-size' ) );
        $footer_background_repeat   = get_theme_mod( 'footer-background-repeat', diamond_get_default( 'footer-background-repeat' ) );
        $footer_background_position = get_theme_mod( 'footer-background-position', diamond_get_default( 'footer-background-position' ) );

        diamond_get_css()->add( array(
            'selectors'    => array( '#footer' ),
            'declarations' => array(
                'background-image'    => 'url("' . $footer_background_image . '")',
                'background-size'     => $footer_background_size,
                'background-repeat'   => $footer_background_repeat,
                'background-position' => $footer_background_position . ' center'
            )
        ) );
    }
}

add_action( 'diamond_css', 'diamond_css_add_rules' );

function diamond_css_add_simple_color_rule( $setting_id, $selectors, $declarations ) {
    $value = maybe_hash_hex_color( get_theme_mod( $setting_id, diamond_get_default( $setting_id ) ) );

    if ( $value === diamond_get_default( $setting_id ) ) {
        return;
    }

    if ( is_string( $selectors ) ) {
        $selectors = array( $selectors );
    }

    if ( is_string( $declarations ) ) {
        $declarations = array(
            $declarations => $value
        );
    }

    diamond_get_css()->add( array(
        'selectors'    => $selectors,
        'declarations' => $declarations
    ) );
}
