<?php
/**
 * Theme functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 */

if ( ! function_exists( 'diamond_setup' ) ) :
/**
 * Theme setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 */
function diamond_setup() {
    /* Register Thumbnails Size
    ================================== */

    /* Main loop */
    add_image_size( 'loop', option::get( 'thumb_width' ), option::get( 'thumb_height' ), true );

    /* Homepage Slider */
    add_image_size( 'featured', 1600 );
    add_image_size( 'featured-small', 800 );

    /* Directory */
    add_image_size( 'thumb-featured-page-3', 250, 160, true );
    add_image_size( 'thumb-featured-page-4', 280, 180, true );

    /* Widget: Featured WooCommerce Products */
    add_image_size( 'woo-featured', 280, 280, true );

    /* Widget: Single Page */
    add_image_size( 'featured-page', 580 );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    // Register nav menus
    register_nav_menus( array(
        'primary' => __( 'Main Menu', 'wpzoom' )
    ) );

    /*
     * Add Jetpack infinite scroll support.
     */
    add_theme_support( 'infinite-scroll', array(
        'container' => 'recent-posts'
    ) );
}
endif;
add_action( 'after_setup_theme', 'diamond_setup' );


if ( ! function_exists( 'diamond_get_the_archive_title' ) ) :
/* Custom Archives titles.
=================================== */
function diamond_get_the_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    }

    if ( is_author() ) {
        $title = sprintf( __( 'Articles by: %s' ), '<span class="vcard">' . get_the_author() . '</span>' );
    }

    return $title;
}
endif;
add_filter( 'get_the_archive_title', 'diamond_get_the_archive_title' );


/* Enable slider.
==================================== */
add_theme_support( 'zoom-post-slider', array(
    'page' => array(
        'video' => false
    )
) );


/* Hack for text separators.
==================================== */

class z_su_separators
{
    private $before = false;
    private $separator;

    public function __construct( $separator = '<span class="separator">/</span>' ) {
        $this->separator = $separator;
    }

    public function separator( $echo = true ) {
        if ( $this->before ) {
            if ( $echo ) {
                echo $this->separator;
            } else {
                return $this->separator;
            }
        }

        $this->before = true;
    }
}



/* Enable Excerpts for Pages
==================================== */

function wpzoom_excerpts_to_pages() {
    add_post_type_support( 'page', 'excerpt' );
}
add_action( 'init', 'wpzoom_excerpts_to_pages' );


/* Replaces the excerpt "more" text by a link
=========================================== */

function new_excerpt_more( $more ) {
    global $post;

    return ' […] <div class="clear"></div><a class="more_link clearfix" href="' . get_permalink( $post->ID ) . '" rel="nofollow">' . __( 'Read More', 'wpzoom' ) . '</a>';
}
add_filter( 'excerpt_more', 'new_excerpt_more' );




/*  Add support for Custom Background
==================================== */

add_theme_support( 'custom-background' );


/*  Reset [gallery] shortcode styles
==================================== */

add_filter( 'gallery_style', create_function( '$a', 'return "<div class=\'gallery\'>";' ) );


/*  Add Support for Shortcodes in Excerpt
========================================== */

add_filter( 'the_excerpt', 'shortcode_unautop' );
add_filter( 'the_excerpt', 'do_shortcode' );

add_filter( 'widget_text', 'shortcode_unautop' );
add_filter( 'widget_text', 'do_shortcode' );


/*  Custom Excerpt Length
==================================== */

function new_excerpt_length( $length ) {
    return (int)option::get( "excerpt_length" ) ? (int)option::get( "excerpt_length" ) : 50;
}

add_filter( 'excerpt_length', 'new_excerpt_length' );


/*  Maximum width for images in posts
=========================================== */

if ( !isset($content_width) ) $content_width = 800;


/* Enqueue scripts and styles for the front end.
=========================================== */

function diamond_scripts() {
    if ( '' !== $google_request = diamond_get_google_font_uri() ) {
        wp_enqueue_style( 'diamond-google-fonts', $google_request, WPZOOM::$themeVersion );
    }

    wp_enqueue_style( 'diamond-google-font-default', '//fonts.googleapis.com/css?family=Montserrat:400,700|Source+Sans+Pro:400,600,700&subset=latin,greek,cyrillic' );

    // Load our main stylesheet.
    wp_enqueue_style( 'diamond-style', get_stylesheet_uri() );

    wp_enqueue_style( 'dashicons' );

    wp_enqueue_style( 'media-queries', get_template_directory_uri() . '/css/media-queries.css', array() );

    wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish.min.js', array( 'jquery' ), '20150317', true );

    wp_enqueue_script( 'headroom', get_template_directory_uri() . '/js/headroom.js', array( 'jquery' ), '20140529', true );

    wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/flexslider.js', array( 'jquery' ), '20140529', true );

    wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/fitvids.js', array() );

    wp_enqueue_script( 'diamond-script', get_template_directory_uri() . '/js/functions.js', array( 'jquery' ), '20150317', true );
}

add_action( 'wp_enqueue_scripts', 'diamond_scripts' );


if ( !function_exists( 'diamond_page_slider_script' ) ) :
    /* JavaScript that powers slider on
     * single pages.
    ==================================== */
    function diamond_page_slider_script() {
        ?>
        <script>
            jQuery(window).load(function ($) {
                jQuery('.page-slider').flexslider({
                    animation: "<?php if (option::get('page_slider_effect') == 'Slide') { ?>slide<?php } else { ?>fade<?php } ?>",
                    animationLoop: true,
                    slideshow: false,
                    useCSS: false,
                    animationSpeed: 300,
                    selector: ".page-slides > li",
                    smoothHeight: true
                });
            });
        </script>
    <?php
    }
endif;
